Package: geospatialsuite
Title: Comprehensive Geospatiotemporal Analysis and Multimodal
        Integration Toolkit
Version: 0.2.0
Authors@R: c(
    person("Olatunde D.", "Akanbi", , "olatunde.akanbi@case.edu", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-7719-2619")),
    person("Vibha", "Mandayam", role = "aut",
           comment = c(ORCID = "0009-0008-8628-9904")),
    person("Yinghui", "Wu", role = "aut",
           comment = c(ORCID = "0000-0003-3991-5155")),
    person("Jeffrey", "Yarus", role = "aut",
           comment = c(ORCID = "0000-0002-9331-9568")),
    person("Erika I.", "Barcelos", , "erika.barcelos@case.edu", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-9273-8488")),
    person("Roger H.", "French", , "roger.french@case.edu", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-6162-0532"))
  )
Maintainer: Olatunde D. Akanbi <olatunde.akanbi@case.edu>
Description: A comprehensive toolkit for geospatiotemporal analysis
    featuring 60+ vegetation indices, advanced raster visualization,
    universal spatial mapping, water quality analysis, CDL crop analysis,
    spatial interpolation, temporal analysis, and terrain analysis.
    Designed for agricultural research, environmental monitoring, remote
    sensing applications, and publication-quality mapping with support for
    any geographic region and robust error handling. Methods include
    vegetation indices calculations (Rouse et al. 1974), NDVI and enhanced
    vegetation indices (Huete et al. 1997)
    <doi:10.1016/S0034-4257(97)00104-1>, (Akanbi et al. 2024) 
    <doi:10.1007/s41651-023-00164-y>, spatial interpolation techniques
    (Cressie 1993, ISBN:9780471002556), water quality indices (McFeeters
    1996) <doi:10.1080/01431169608948714>, and crop data layer analysis
    (USDA NASS 2024)
    <https://www.nass.usda.gov/Research_and_Science/Cropland/>.  Funding:
    This material is based upon financial support by the National Science
    Foundation, EEC Division of Engineering Education and Centers, NSF
    Engineering Research Center for Advancing Sustainable and Distributed
    Fertilizer production (CASFER), NSF 20-553 Gen-4 Engineering Research
    Centers award 2133576.
License: MIT + file LICENSE
URL: https://exelegch.github.io/geospatialsuite-docs/,
        https://github.com/cwru-sdle/geospatialsuite,
        https://joss.theoj.org/papers/10.21105/joss.09536
BugReports: https://github.com/cwru-sdle/geospatialsuite/issues
Depends: R (>= 3.5.0)
Imports: dplyr, ggplot2, graphics, grDevices, htmlwidgets, leaflet,
        magrittr, mice, parallel, RColorBrewer, rnaturalearth, sf,
        stats, stringr, terra, tigris, tools, utils, viridis
Suggests: knitr, pkgnet, rmarkdown, kableExtra, nhdplusTools, zipcodeR,
        tidygeocoder, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-08 03:48:49 UTC; oda10
Author: Olatunde D. Akanbi [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-7719-2619>),
  Vibha Mandayam [aut] (ORCID: <https://orcid.org/0009-0008-8628-9904>),
  Yinghui Wu [aut] (ORCID: <https://orcid.org/0000-0003-3991-5155>),
  Jeffrey Yarus [aut] (ORCID: <https://orcid.org/0000-0002-9331-9568>),
  Erika I. Barcelos [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-9273-8488>),
  Roger H. French [aut, cph] (ORCID:
    <https://orcid.org/0000-0002-6162-0532>)
Repository: CRAN
Date/Publication: 2026-05-08 04:21:47 UTC
Built: R 4.5.2; ; 2026-05-08 06:29:06 UTC; unix
